/**
 * Base class for search strategies with common functionality
 */
export class BaseSearchStrategy {
    config;
    constructor(config) {
        this.config = config;
    }
    /**
     * Exact search implementation for backward compatibility
     */
    exactSearch(query, entities) {
        const lowerQuery = query.toLowerCase();
        return entities.filter(e => {
            const entityTags = e.tags || [];
            return (e.name.toLowerCase().includes(lowerQuery) ||
                e.entityType.toLowerCase().includes(lowerQuery) ||
                e.observations.some(o => o.toLowerCase().includes(lowerQuery)) ||
                entityTags.some(tag => tag.toLowerCase().includes(lowerQuery)));
        });
    }
    /**
     * Filter entities by exact tags
     */
    filterByExactTags(entities, exactTags, tagMatchMode = 'any') {
        return entities.filter(entity => {
            const entityTags = entity.tags || [];
            if (tagMatchMode === 'all') {
                return exactTags.every(tag => entityTags.includes(tag));
            }
            else {
                return exactTags.some(tag => entityTags.includes(tag));
            }
        });
    }
}
//# sourceMappingURL=base-strategy.js.map