import Database from 'better-sqlite3';
import { Entity } from '../../core.js';
import { SearchConfig } from '../types.js';
import { BaseSearchStrategy } from './base-strategy.js';
/**
 * SQLite search strategy - uses client-side fuzzy search only
 * SQLite doesn't have built-in fuzzy search capabilities like PostgreSQL,
 * so we always use Fuse.js for fuzzy searching
 */
export declare class SQLiteFuzzyStrategy extends BaseSearchStrategy {
    private db;
    private project;
    constructor(config: SearchConfig, db: Database.Database, project: string);
    canUseDatabase(): boolean;
    searchDatabase(query: string, threshold: number, project?: string): Promise<Entity[]>;
    searchClientSide(entities: Entity[], query: string): Entity[];
    /**
     * Get all entities for a project from SQLite database
     * This is used to load entities for client-side search
     */
    getAllEntities(project?: string): Promise<Entity[]>;
    /**
     * Perform exact search at database level for better performance
     * This can be used as an optimization for exact searches
     */
    searchExact(query: string, project?: string): Promise<Entity[]>;
    /**
     * Safely parse JSON with fallback to default value
     */
    private safeJsonParse;
}
//# sourceMappingURL=sqlite-strategy.d.ts.map