import { Entity } from '../../core.js';
/**
 * Performance measurement utilities for benchmarking
 */
export declare class PerformanceUtils {
    /**
     * Measure execution time of an async function
     */
    static measureTime<T>(fn: () => Promise<T>): Promise<{
        result: T;
        timeMs: number;
    }>;
    /**
     * Measure execution time of a sync function
     */
    static measureTimeSync<T>(fn: () => T): {
        result: T;
        timeMs: number;
    };
    /**
     * Run a function multiple times and get statistics
     */
    static runBenchmark<T>(fn: () => Promise<T>, iterations?: number): Promise<{
        results: T[];
        times: number[];
        avgTime: number;
        minTime: number;
        maxTime: number;
        medianTime: number;
        stdDev: number;
    }>;
    /**
     * Measure memory usage before and after a function execution
     */
    static measureMemory<T>(fn: () => Promise<T>): Promise<{
        result: T;
        memoryUsed: number;
        heapUsedBefore: number;
        heapUsedAfter: number;
    }>;
    /**
     * Generate test entities for performance testing
     */
    static generateTestEntities(count: number): Entity[];
    /**
     * Generate realistic test entities with varied content
     */
    static generateRealisticTestEntities(count: number): Entity[];
    /**
     * Format benchmark results for display
     */
    static formatBenchmarkResults(results: {
        avgTime: number;
        minTime: number;
        maxTime: number;
        medianTime: number;
        stdDev: number;
    }): string;
    /**
     * Format memory usage for display
     */
    static formatMemoryUsage(bytes: number): string;
}
//# sourceMappingURL=performance-utils.d.ts.map